@@ -21,15 +21,23 @@ class Dataset:
 
     @property
     def publisher(self):
-        return self.publisher
+        return self._publisher
 
     @publisher.setter
     def publisher(self, publisher):
         self._publisher = publisher
 
+    @property
+    def description(self):
+        return self._description
+
+    @description.setter
+    def description(self, description):
+        self._description = description
+
     @property
     def visibility(self):
-        return self.visibility
+        return self._visibility
 
     @visibility.setter
     def visibility(self, visibility):
@@ -39,7 +47,7 @@ class Dataset:
         result = dict()
 
         for item in ATTRIBUTES:
-            attr = getattr(self, item)
+            attr = getattr(self, item, "")
 
             if attr and attr != '':
                 result[item] = attr
